==> enterprisemodules-pg_profile-0.1.1.tar.gz: enterprisemodules-pg_profile-0.1.1/README.md <==

[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

1. [Overview](#overview)
2. [License](#license)
3. [Description - What the module does and why it is useful](#description)
4. [Setup](#setup)
  * [Requirements](#requirements)
  * [Installing the pg_profile module](#installing-the-pg_profile-module)
5. [Usage - Configuration options and additional functionality](#usage)
6. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
7. [Limitations - OS compatibility, etc.](#limitations)

## Overview

The `pg_profile` module allows an easy path from first simple installation to a fully customized Enterprise setup. It is part of our family of Puppet modules to install, manage and secure Postgres databases with Puppet. Besides the `pg_profile` module, this family also contains:

- [pg_config](https://www.enterprisemodules.com/shop/products/puppet-pg_config-module) For configuring every aspect of your Postgres database
- [pg_secured](https://www.enterprisemodules.com/shop/products/puppet-postgres-security-module) To secure your databases according to the CIS benchmarks.

This module support Postgres 10, 11, 12, and 13.


## License

Most of the [Enterprise Modules](https://www.enterprisemodules.com) modules are commercial modules. This one is **NOT**. It is an Open Source module. You are free to use it any way you like. It, however, is based on our commercial Puppet Postgres modules.

## Description

The `pg_profile::database` class contains all the Puppet code to install, create and populate an Postgres database. This class is an easy way to get started. It contains the following steps:

- em_license          ( Manage Enterprise Modules Licenses)
- sysctl              ( Setup any sysctl parameters)
- limits              ( Setup any security limits)
- groups_and_users    ( Setup required groups and users)
- packages            ( Setup any required after_packages)
- firewall            ( Setup the firewall)
- db_software         ( Install the postgres software)
- db_init             ( Take care of initial database stup)
- db_startup          ( Manage starting the database)
- db_roles            ( Ensure required Postgres database roles)
- db_definition       ( Ensure required Postgress databases)
- db_parameters       ( Ensure required Postgres database settings)
- db_tablespaces      ( Ensure needed tablespaces)
- db_schemas          ( Ensure needed database schema's)
- db_records          ( Ensure required database records (for settings))

All these steps have a default implementation. This implementation is suitable to get started with. These classed all have parameters you can customize through hiera values. The defaults are specified in the module's `data/default.yaml` file.

But sometimes this is not enough and you would like to add some extra definitions, you can, for example, add a Puppet class to be executed after the `systctl` stage is done and before the `limits` is done. You can do this by adding the next line to your yaml data:

```yaml
pg_profile::database::before_sysctl:   my_profile::my_extra_class
```
or after:

```yaml
pg_profile::database::after_sysctl:   my_profile::my_extra_class
```

If you want to, you can also skip this provided class:

```yaml
pg_profile::database::sysctl:   skip
```

Or provide your own implementation:

```yaml
pg_profile::database::sysctl:   my_profile::my_own_implementation
```

This mechanism can be used for all named steps and makes it easy to move from an easy setup with a running standard database to a fully customized setup using a lot of your own classes plugged in.

Check [here](https://www.enterprisemodules.com/docs/pg_profile/description.html) to see the full documentation for this module.

## Setup

### Requirements

The [`pg_profile`](https://www.enterprisemodules.com/shop/products/puppet-ora_config-module) module requires:
- Puppet module [`enterprisemodules-pg_config`](https://forge.puppet.com/enterprisemodules/ora_config) installed.
- Puppet module [`enterprisemodules-easy_type`](https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet module [`enterprisemodules/pg_secured`](https://forge.puppet.com/enterprisemodules/ora_cis) installed.
- Puppet module [`ipcrm-echo`](https://forge.puppet.com/ipcrm/echo) installed.
- Puppet module [`herculesteam-augeasproviders_core`](https://forge.puppet.com/herculesteam/augeasproviders_core) installed.
- Puppet module [`herculesteam-augeasproviders_sysctl`](https://forge.puppet.com/herculesteam/augeasproviders_sysctl) installed.
- Puppet module [`saz-limits`](https://forge.puppet.com/saz/limits) installed.
- Puppet module [`puppetlabs-firewall`](https://forge.puppet.com/puppetlabs/firewall) installed.
- Puppet module [`crayfishx-firewalld`](https://forge.puppet.com/crayfishx/firewalld) installed.
- Puppet module [`puppetlabs-stdlib`](https://forge.puppet.com/puppetlabs/stdlib) installed.
- Puppet version 5.0 or higher. Can be Puppet Enterprise or Puppet Open Source
- Postgres 10 higher
- A valid Enterprise Modules license for usage.
- Runs on most Linux systems.
- Windows systems are **NOT** supported

### Installing the pg_profile module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/pg_profile'               ,'x.x.x'
```

Then use the `librarian-puppet` or `r10K` to install the software.

You can also install the software using the `puppet module`  command:

```
puppet module install enterprisemodules-pg_profile
```

## Usage

To get started, include the `pg_profile::database` class in your role. Run Puppet and you have a running Postgres database.

## Reference

Here you can find some more information regarding this puppet module:

- [The `pg_profile` documentation](https://www.enterprisemodules.com/docs/pg_profile/description.html)


## Limitations

This module runs on most Linux versions. It requires a puppet version higher than 5. The module does **NOT** run on windows systems.

==> enterprisemodules-pg_profile-0.5.0.tar.gz: enterprisemodules-pg_profile-0.5.0/README.md <==

[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

- [Overview](#overview)
- [License](#license)
- [Description](#description)
- [Setup](#setup)
  - [Requirements](#requirements)
  - [Installing the pg_profile module](#installing-the-pg_profile-module)
- [Usage](#usage)
- [Reference](#reference)
- [Limitations](#limitations)

## Overview

The `pg_profile` module allows an easy path from first simple installation to a fully customized Enterprise setup. It is part of our family of Puppet modules to install, manage and secure Postgres databases with Puppet. Besides the `pg_profile` module, this family also contains:

- [pg_config](https://www.enterprisemodules.com/shop/products/puppet-pg_config-module) For configuring every aspect of your Postgres database
- [pg_secured](https://www.enterprisemodules.com/shop/products/puppet-postgres-security-module) To secure your databases according to the CIS benchmarks.

This module support Postgres 10, 11, 12, and 13.


## License

Most of the [Enterprise Modules](https://www.enterprisemodules.com) modules are commercial modules. This one is **NOT**. It is an Open Source module. You are free to use it any way you like. It, however, is based on our commercial Puppet Postgres modules.

## Description

The `pg_profile::database` class contains all the Puppet code to install, create and populate an Postgres database. This class is an easy way to get started. It contains the following steps:

- em_license          ( Manage Enterprise Modules Licenses)
- disable_thp         ) Disable transparant Huge pages)
- sysctl              ( Setup any sysctl parameters)
- limits              ( Setup any security limits)
- groups_and_users    ( Setup required groups and users)
- packages            ( Setup any required after_packages)
- firewall            ( Setup the firewall)
- db_software         ( Install the postgres software)
- db_clusters         ( Manage the database clusters )
- db_instances        ( Manage the database instances )
- db_roles            ( Ensure required Postgres database roles)
- db_definition       ( Ensure required Postgress databases)
- db_parameters       ( Ensure required Postgres database settings)
- db_tablespaces      ( Ensure needed tablespaces)
- db_schemas          ( Ensure needed database schema's)
- db_records          ( Ensure required database records (for settings))

All these steps have a default implementation. This implementation is suitable to get started with. These classed all have parameters you can customize through hiera values. The defaults are specified in the module's `data/default.yaml` file.

But sometimes this is not enough and you would like to add some extra definitions, you can, for example, add a Puppet class to be executed after the `systctl` stage is done and before the `limits` is done. You can do this by adding the next line to your yaml data:

```yaml
pg_profile::database::before_sysctl:   my_profile::my_extra_class
```
or after:

```yaml
pg_profile::database::after_sysctl:   my_profile::my_extra_class
```

If you want to, you can also skip this provided class:

```yaml
pg_profile::database::sysctl:   skip
```

Or provide your own implementation:

```yaml
pg_profile::database::sysctl:   my_profile::my_own_implementation
```

This mechanism can be used for all named steps and makes it easy to move from an easy setup with a running standard database to a fully customized setup using a lot of your own classes plugged in.

Check [here](https://www.enterprisemodules.com/docs/pg_profile/description.html) to see the full documentation for this module.

## Setup

### Requirements

The [`pg_profile`](https://www.enterprisemodules.com/shop/products/puppet-ora_config-module) module requires:
- Puppet module [`enterprisemodules-pg_config`](https://forge.puppet.com/enterprisemodules/ora_config) installed.
- Puppet module [`enterprisemodules-easy_type`](https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet module [`enterprisemodules/pg_secured`](https://forge.puppet.com/enterprisemodules/ora_cis) installed.
- Puppet module [`ipcrm-echo`](https://forge.puppet.com/ipcrm/echo) installed.
- Puppet module [`puppet-augeasproviders_core`](https://forge.puppet.com/herculesteam/augeasproviders_core) installed.
- Puppet module [`herculesteam-augeasproviders_sysctl`](https://forge.puppet.com/herculesteam/augeasproviders_sysctl) installed.
- Puppet module [`herculesteam-augeasproviders_grub`](https://forge.puppet.com/herculesteam/augeasproviders_grub) installed.
- Puppet module [`saz-limits`](https://forge.puppet.com/saz/limits) installed.
- Puppet module [`puppetlabs-firewall`](https://forge.puppet.com/puppetlabs/firewall) installed.
- Puppet module [`puppet-firewalld`](https://forge.puppet.com/puppet/firewalld) installed.
- Puppet module [`puppetlabs-stdlib`](https://forge.puppet.com/puppetlabs/stdlib) installed.
- Puppet version 5.0 or higher. Can be Puppet Enterprise or Puppet Open Source
- Postgres 10 higher
- A valid Enterprise Modules license for usage.
- Runs on most Linux systems.
- Windows systems are **NOT** supported

### Installing the pg_profile module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/pg_profile'               ,'x.x.x'
```

Then use the `librarian-puppet` or `r10K` to install the software.

You can also install the software using the `puppet module`  command:

```
puppet module install enterprisemodules-pg_profile
```

## Usage

To get started, include the `pg_profile::database` class in your role. Run Puppet and you have a running Postgres database.

## Reference

Here you can find some more information regarding this puppet module:

- [The `pg_profile` documentation](https://www.enterprisemodules.com/docs/pg_profile/description.html)


## Limitations

This module runs on most Linux versions. It requires a puppet version higher than 5. The module does **NOT** run on windows systems.
